@@ -3,12 +3,12 @@ use v5.14.0;
 use strict;
 use warnings;
 # ABSTRACT: like mv, but clever
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use Exporter qw(import);
 our @EXPORT = qw(mvr);
 
-use Path::Tiny;
+use Path::Tiny 0.034;
 use Try::Tiny;
 use Carp;
 
@@ -21,12 +21,7 @@ my $duplicates = sub {
     return if $A->stat->size != $B->stat->size; # avoid reading file off disk
 
     # Pull out the big guns
-    require Digest::MD5;
-    return
-        Digest::MD5->new->addfile( $A->filehandle('<', ':raw') )->digest
-        eq
-        Digest::MD5->new->addfile( $B->filehandle('<', ':raw') )->digest
-    ;
+    return $A->digest eq $B->digest;
 };
 
 sub mvr {
@@ -39,7 +34,10 @@ sub mvr {
     croak sprintf("target `%s' is not a directory\n", $dest)
         if @{ $args{source} } > 1 and !$dest_is_dir;
 
+    STDOUT->autoflush(1) if $VERBOSE;
     foreach my $from ( map { path($_) } @{ $args{source} } ) {
+        print "\r${from}\e[K" if $VERBOSE == 1;
+
         unless ($from->exists) {
             carp sprintf("Cannot stat `%s': No such file or directory\n", $from);
             next;
@@ -50,13 +48,13 @@ sub mvr {
 
         if ($to->exists) {
             if ($args{deduplicate}) {
-                STDERR->autoflush(1);
-                print STDERR "File already exists; checking for duplication..." if $VERBOSE;
+                print STDERR "File already exists; checking for duplication..."
+                    if $VERBOSE > 1;
                 if ($duplicates->($from, $to)) {
                     printf STDERR
-                        " `' and `%s' are duplicates; removing the source file.\n",
+                        " `%s' and `%s' are duplicates; removing the source file.\n",
                         $from->basename, $to->basename
-                        if $VERBOSE;
+                        if $VERBOSE > 1;
                     $from->remove;
                     $to->touch;
                     next;
@@ -65,7 +63,7 @@ sub mvr {
                     printf STDERR
                         " `%s' and `%s' are not duplicates.\n",
                         $from->basename, $to->basename
-                        if $VERBOSE;
+                        if $VERBOSE > 1;
                 }
             }
 
@@ -78,23 +76,21 @@ sub mvr {
             );
             printf STDERR "File already exists; renaming `%s' to `%s'\n",
                 $from->basename, $to->basename
-                if $VERBOSE;
+                if $VERBOSE > 1;
         }
 
         try {
             $from->move($to);
         }
         catch {
-            die $_ unless $_->isa('autodie::exception');
-
             use POSIX qw(:errno_h);
-            if ($_->errno == EXDEV) { # Invalid cross-device link
-                STDERR->autoflush(1);
+            if ($_->{err} == EXDEV) { # Invalid cross-device link
                 printf STDERR "File can't be renamed across filesystems; copying `%s' to `%s' instead...",
                     $from->basename, $to->basename
-                    if $VERBOSE;
+                    if $VERBOSE > 1;
                 $from->copy($to);
-                print STDERR " done. Removing original file.\n" if $VERBOSE;
+                $to->touch( $from->stat->mtime );
+                print STDERR " done. Removing original file.\n" if $VERBOSE > 1;
                 $from->remove;
             }
             else {
@@ -110,7 +106,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -118,7 +114,7 @@ App::mvr - like mv, but clever
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 FUNCTIONS
 
